@@ -156,7 +156,7 @@ class Hisat2(object):
             raise Exception(f"Poor alignment: {uniquely_aligned:,} ({per_aligned}%)")
 
     @staticmethod
-    def _samtools(stats_file: Path) -> pd.DataFrame:
+    def _samtools(stats_file: str) -> pd.DataFrame:
         return parse_samtools_stats(stats_file)[
             [
                 "reads_MQ0",
@@ -171,5 +171,5 @@ class Hisat2(object):
         ]
 
     @staticmethod
-    def _bamtools(stats_file: Path) -> pd.DataFrame:
+    def _bamtools(stats_file: str) -> pd.DataFrame:
         return parse_bamtools_stats(stats_file)[["Percent Forward", "Percent Reverse"]]
